@@ -4,7 +4,7 @@ use strict;
 #
 # crlpublish
 #
-# Copyright (C) 2014, Kevin Cody-Little <kcody@cpan.org>
+# Copyright (C) 2014, Kevin Cody-Little <kcodyjr@gmail.com>
 #
 # Portions derived from crlpublisher.sh, original copyright follows:
 #
@@ -25,44 +25,10 @@ use strict;
 #
 ###############################################################################
 
-=head1 NAME
-
-EJBCA::CrlPublish::Config
-
-=head1 SYNOPSIS
-
-Loads and queries the contents of configuration files.
-
-All functions should be called as class methods.
-
-=cut
-
-
-###############################################################################
-# Library Dependencies
-
-our $VERSION = 0.4;
-
-
-###############################################################################
-# Config Value Storage and Retrieval
-
-=head1 CONFIG VALUE METHODS
-
-=cut
-
 { # private lexicals begin
 
 my %CONFIG = ();
 
-=head2 $class->configValue( $section, $name )
-
-=head2 $class->configValue( $section, $name, $value )
-
-Sets or retrieves a single value in a specific section.
-
-=cut
-
 sub configValue {
 	my ( $class, $section, $name, $value ) = @_;
 
@@ -75,13 +41,6 @@ sub configValue {
 	return $ref->{$name};
 }
 
-=head2 $class->applySection( $section, $target )
-
-Applies each attribute in the given section to the given target, by calling
-$target->attributeName( attributeValue ).
-
-=cut
-
 sub applySection {
 	my ( $class, $section, $target ) = @_;
 
@@ -99,15 +58,7 @@ sub applySection {
 
 
 ###############################################################################
-
-=head1 DATA IMPORT METHOD
-
-=head2 $class->importAllFiles( $directory )
-
-Reads all of the config files in the given directory and stores their
-contents using the configValue method described above.
-
-=cut
+# Data Import Methods
 
 sub importAllFiles {
 	my ( $class, $path ) = @_;
@@ -243,15 +194,6 @@ sub parseFile {
 }
 
 
-###############################################################################
-
-=head1 AUTHOR
-
-Kevin Cody-Little <kcody@cpan.org>
-
-=cut
-
-
 ###############################################################################
 ####################################### EOF ###################################
 ###############################################################################
