@@ -25,31 +25,8 @@ use strict;
 #
 ###############################################################################
 
-=head1 NAME
-
-EJBCA::CrlPublish::Method::scp
-
-=head1 SYNOPSIS
-
-Implements publishing via scp.
-
-Updates are atomic; that is, CRLs are transferred to a temporary file and
-then renamed into place, so there is no period of time that an intact CRL
-cannot be retrieved from the server.
-
-=cut
-
-
-###############################################################################
-# Library Dependencies
-
 use base 'EJBCA::CrlPublish::Method';
 
-our $VERSION = '0.4.1';
-
-
-###############################################################################
-# Implementation
 
 sub validate {
 	my $self = shift;
@@ -61,7 +38,7 @@ sub validate {
 sub publish {
 	my $self = shift;
 
-	my @args = ();
+	my @args = ( 'scp' );
 
 	my $host = $self->target->remoteHost;
 	my $path = $self->target->remotePath;
@@ -84,32 +61,19 @@ sub publish {
 
 	$self->checkFileType( 'CRL file', $source );
 
-	my $t_host  = $user ? $user . '@' : '';
-	   $t_host .= $host;
-	my $t_file  = $path . '/' . $file;
-	my $t_temp  = $t_file . '.new';
+	my $target = '';
+	$target .= $user . '@' if $user;
+	$target .= $host . ':' . $path . '/' . $file;
 
-	my $target = $t_host . ':' . $t_temp;
+	push @args, $source, $target;
 
-	system( 'scp', @args, $source, $target ) == 0
+	system( @args ) == 0
 		or die "Failed to scp: $?";
 
-	system( 'ssh', @args, $t_host, 'mv', $t_temp, $t_file ) == 0
-		or die "Failed to rename: $?";	
-
 	return 1;
 }
 
 
-###############################################################################
-
-=head1 AUTHOR
-
-Kevin Cody-Little <kcody@cpan.org>
-
-=cut
-
-
 ###############################################################################
 ####################################### EOF ###################################
 ###############################################################################
